/*
** Graphical User Interface using the Be API
** for Multiface Two ACEpansion
*/

#include <Alert.h>
#include <Box.h>
#include <Button.h>
#include <GroupView.h>
#include <Resources.h>

#include <acepansion/lib_header.h>

#include "acepansion.h"
#include "interface.h"
#define CATCOMP_NUMBERS
#include "generated/locale_strings.h" /* catalog string ids */

#include "../../Haiku/RichButton.h"

class ColorButton: public BButton
{
	public:
	ColorButton(rgb_color c, const char* label, uint32 msg)
		: BButton("button", label, new BMessage(msg))
	{
		fColor = c;
	}

	void AttachedToWindow() override
	{
		BButton::AttachedToWindow();

		SetLowColor(fColor);

		SetTarget(Parent());
	}

	rgb_color fColor;
};

class RootView: public BBox
{
public:
	RootView(const char* label, struct ACEpansionPlugin* plugin)
		: BBox("plugin root")
		, myPlugin(plugin)
	{
		SetLabel(label);
	}

	void MessageReceived(BMessage* msg) override
	{
		if (msg->what == 'STOP') {
			Plugin_TriggerStop(myPlugin);
		} else if (msg->what == 'REST') {
			Plugin_TriggerReset(myPlugin);
		} else {
			BBox::MessageReceived(msg);
		}
	}

private:
	struct ACEpansionPlugin* myPlugin;
};

/*
** Function which is called to initialize commons just
** after the library was loaded into memory and prior
** to any other API call
**
** This is the good place to open our required libraries
** and create our MUI custom classes
*/
BOOL GUI_InitResources(VOID)
{
	return TRUE;
}

/*
** Function which is called to free commons just before
** the library is expurged from memory
**
** This is the good place to close our required libraries
** and destroy our MUI custom classes
*/
void GUI_FreeResources(void)
{
}

/*
** Function which is called from CreatePlugin() to build the GUI
*/
Object* GUI_Create(struct ACEpansionPlugin* myPlugin)
{
	BBox* box = new RootView(GetString(MSG_CONTROLS), myPlugin);
	BGroupView* gv = new BGroupView(B_HORIZONTAL);
	gv->GroupLayout()->SetInsets(B_USE_WINDOW_SPACING);
	box->AddChild(gv);
	gv->AddChild(new ColorButton(make_color(255, 32, 32), "STOP", 'STOP'));
	gv->AddChild(new ColorButton(make_color(255, 255, 32), "RESET", 'REST'));

	return (Object*)box;
}

/*
** Function which is called from DeletePlugin() to delete the GUI
*/
VOID GUI_Delete(Object *gui)
{
	BView* view = (BView*)gui;
	BWindow* window = view->Window();
	window->Lock();
	view->RemoveSelf();
	window->Unlock();
	delete view;
}



/*
** Functions called from the plugin
*/
VOID GUI_NotifyROMNotFound(UNUSED Object *gui, CONST_STRPTR rom)
{
	BString str;
	str.SetToFormat(GetString(MSG_NO_ROM), rom);
	BAlert* alert = new RichAlert(GetString(MSG_TITLE), str.String(),
		GetString(MSG_OK), NULL, NULL, B_WIDTH_AS_USUAL, B_STOP_ALERT);
	alert->Go();
}

